@@ -18,13 +18,12 @@
  */
 
 #include "config.h"
-
 #include "empathy-password-dialog.h"
 
 #include <glib/gi18n-lib.h>
 
 #define DEBUG_FLAG EMPATHY_DEBUG_SASL
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 G_DEFINE_TYPE (EmpathyPasswordDialog, empathy_password_dialog,
     EMPATHY_TYPE_BASE_PASSWORD_DIALOG)
