@@ -18,15 +18,15 @@
  */
 
 #include "config.h"
-
 #include "empathy-sound-manager.h"
 
 #include <glib/gi18n-lib.h>
 
+#include "empathy-gsettings.h"
+#include "empathy-utils.h"
+
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
-#include <libempathy/empathy-gsettings.h>
-#include <libempathy/empathy-utils.h>
+#include "empathy-debug.h"
 
 typedef struct {
   EmpathySound sound_id;
