@@ -19,12 +19,12 @@
  */
 
 #include "config.h"
-
 #include "empathy-connection-managers.h"
+
 #include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 static GObject *managers = NULL;
 
