@@ -20,11 +20,10 @@
  */
 
 #include "config.h"
-
 #include "empathy-request-util.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_DISPATCHER
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 void
 empathy_chat_with_contact (EmpathyContact *contact,
