@@ -20,14 +20,13 @@
  */
 
 #include "config.h"
-
-#include <libempathy/empathy-camera-monitor.h>
-#include <libempathy/empathy-gsettings.h>
-
 #include "empathy-camera-menu.h"
 
+#include "empathy-camera-monitor.h"
+#include "empathy-gsettings.h"
+
 #define DEBUG_FLAG EMPATHY_DEBUG_VOIP
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 struct _EmpathyCameraMenuPrivate
 {
