@@ -18,16 +18,14 @@
  */
 
 #include "config.h"
-
-#include <gtk/gtk.h>
-#include <pulse/glib-mainloop.h>
-
 #include "empathy-mic-monitor.h"
 
-#include <libempathy/empathy-utils.h>
+#include <pulse/glib-mainloop.h>
+
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_VOIP
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 enum
 {
