@@ -22,45 +22,42 @@
  */
 
 #include "config.h"
+#include "empathy-roster-window.h"
 
 #include <sys/stat.h>
 #include <glib/gi18n.h>
 
-#include <libempathy/empathy-utils.h>
-#include <libempathy/empathy-request-util.h>
-#include <libempathy/empathy-chatroom-manager.h>
-#include <libempathy/empathy-gsettings.h>
-#include <libempathy/empathy-gsettings.h>
-#include <libempathy/empathy-status-presets.h>
-#include <libempathy/empathy-presence-manager.h>
-#include <libempathy/empathy-client-factory.h>
-
-#include <libempathy-gtk/empathy-contact-blocking-dialog.h>
-#include <libempathy-gtk/empathy-contact-search-dialog.h>
-#include <libempathy-gtk/empathy-geometry.h>
-#include <libempathy-gtk/empathy-gtk-enum-types.h>
-#include <libempathy-gtk/empathy-individual-dialogs.h>
-#include <libempathy-gtk/empathy-roster-model-manager.h>
-#include <libempathy-gtk/empathy-roster-view.h>
-#include <libempathy-gtk/empathy-new-message-dialog.h>
-#include <libempathy-gtk/empathy-new-call-dialog.h>
-#include <libempathy-gtk/empathy-log-window.h>
-#include <libempathy-gtk/empathy-presence-chooser.h>
-#include <libempathy-gtk/empathy-ui-utils.h>
-
+#include "empathy-about-dialog.h"
 #include "empathy-accounts-dialog.h"
 #include "empathy-call-observer.h"
 #include "empathy-chat-manager.h"
-#include "empathy-roster-window.h"
-#include "empathy-preferences.h"
-#include "empathy-about-dialog.h"
-#include "empathy-new-chatroom-dialog.h"
+#include "empathy-chatroom-manager.h"
 #include "empathy-chatrooms-window.h"
+#include "empathy-contact-blocking-dialog.h"
+#include "empathy-contact-search-dialog.h"
 #include "empathy-event-manager.h"
 #include "empathy-ft-manager.h"
+#include "empathy-geometry.h"
+#include "empathy-gsettings.h"
+#include "empathy-gsettings.h"
+#include "empathy-gtk-enum-types.h"
+#include "empathy-individual-dialogs.h"
+#include "empathy-log-window.h"
+#include "empathy-new-call-dialog.h"
+#include "empathy-new-chatroom-dialog.h"
+#include "empathy-new-message-dialog.h"
+#include "empathy-preferences.h"
+#include "empathy-presence-chooser.h"
+#include "empathy-presence-manager.h"
+#include "empathy-request-util.h"
+#include "empathy-roster-model-manager.h"
+#include "empathy-roster-view.h"
+#include "empathy-status-presets.h"
+#include "empathy-ui-utils.h"
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 /* Flashing delay for icons (milliseconds). */
 #define FLASH_TIMEOUT 500
@@ -478,7 +475,7 @@ static void
 display_page_no_account (EmpathyRosterWindow *self)
 {
   display_page_message (self,
-      _("You need to setup an account to see contacts here."),
+      _("You need to set up an account to see contacts here."),
       PAGE_MESSAGE_FLAG_ACCOUNTS);
 }
 
@@ -1260,44 +1257,19 @@ roster_window_favorite_chatroom_join (EmpathyChatroom *chatroom)
 }
 
 static void
-roster_window_join_chatroom_menu_activate_cb (GSimpleAction *action,
+roster_window_favorite_chatroom_menu_activate_cb (GAction *action,
     GVariant *parameter,
-    gpointer user_data)
+    EmpathyChatroom *chatroom)
 {
-  EmpathyRosterWindow *self = user_data;
-  const gchar *room, *path;
-  EmpathyClientFactory *factory;
-  TpAccount *account;
-  GError *error = NULL;
-  EmpathyChatroom *chatroom;
-
-  g_variant_get (parameter, "(&s&s)", &room, &path);
-
-  factory = empathy_client_factory_dup ();
-
-  account = tp_simple_client_factory_ensure_account (
-      TP_SIMPLE_CLIENT_FACTORY (factory), path, NULL, &error);
-  if (account == NULL)
-    {
-      DEBUG ("Failed to get account '%s': %s", path, error->message);
-      g_error_free (error);
-      goto out;
-    }
-
-  chatroom = empathy_chatroom_manager_find (self->priv->chatroom_manager,
-      account, room);
-  if (chatroom == NULL)
-    {
-      DEBUG ("Failed to get chatroom '%s' on '%s': %s",
-          room, path, error->message);
-      g_error_free (error);
-      goto out;
-    }
-
   roster_window_favorite_chatroom_join (chatroom);
+}
 
-out:
-  g_object_unref (factory);
+static gchar *
+dup_join_action_name (EmpathyChatroom *chatroom,
+    gboolean prefix)
+{
+  return g_strconcat (prefix ? "win." : "", "join-",
+      empathy_chatroom_get_name (chatroom), NULL);
 }
 
 static void
@@ -1305,26 +1277,35 @@ roster_window_favorite_chatroom_menu_add (EmpathyRosterWindow *self,
     EmpathyChatroom *chatroom)
 {
   GMenuItem *item;
-  const gchar *name, *account_name, *account_path;
-  TpAccount *account;
-  gchar *label;
-
-  account = empathy_chatroom_get_account (chatroom);
+  const gchar *name, *account_name;
+  gchar *label, *action_name;
+  GAction *action;
 
   name = empathy_chatroom_get_name (chatroom);
-  account_name = tp_account_get_display_name (account);
-  account_path = tp_proxy_get_object_path (account);
+  account_name = tp_account_get_display_name (
+      empathy_chatroom_get_account (chatroom));
 
   label = g_strdup_printf ("%s (%s)", name, account_name);
+  action_name = dup_join_action_name (chatroom, FALSE);
 
-  item = g_menu_item_new (label, NULL);
-  g_menu_item_set_action_and_target (item, "win.join", "(ss)",
-      name, account_path);
+  action = (GAction *) g_simple_action_new (action_name, NULL);
+  g_free (action_name);
+
+  g_signal_connect (action, "activate",
+      G_CALLBACK (roster_window_favorite_chatroom_menu_activate_cb),
+      chatroom);
+
+  g_action_map_add_action (G_ACTION_MAP (self), action);
+
+  action_name = dup_join_action_name (chatroom, TRUE);
+
+  item = g_menu_item_new (label, action_name);
   g_menu_item_set_attribute (item, "room-name", "s", name);
-  g_menu_item_set_attribute (item, "account-path", "s", account_path);
   g_menu_append_item (self->priv->rooms_section, item);
 
   g_free (label);
+  g_free (action_name);
+  g_object_unref (action);
 }
 
 static void
@@ -1342,46 +1323,26 @@ roster_window_favorite_chatroom_menu_removed_cb (
     EmpathyRosterWindow *self)
 {
   GList *chatrooms;
-  guint i, n;
-  TpAccount *account;
-  const gchar *account_path;
+  gchar *act;
+  gint i;
 
-  account = empathy_chatroom_get_account (chatroom);
-  account_path = tp_proxy_get_object_path (account);
+  act = dup_join_action_name (chatroom, TRUE);
 
-  n = g_menu_model_get_n_items (G_MENU_MODEL (self->priv->rooms_section));
+  g_action_map_remove_action (G_ACTION_MAP (self), act);
 
-  for (i = 0; i < n; i++)
+  for (i = 0; i < g_menu_model_get_n_items (
+        G_MENU_MODEL (self->priv->rooms_section)); i++)
     {
-      gchar *tmp;
+      const gchar *name;
 
-      if (!g_menu_model_get_item_attribute (
-            G_MENU_MODEL (self->priv->rooms_section), i,
-            "room-name", "s", &tmp))
-        continue;
-
-      if (tp_strdiff (tmp, empathy_chatroom_get_name (chatroom)))
+      if (g_menu_model_get_item_attribute (
+            G_MENU_MODEL (self->priv->rooms_section), i, "room-name",
+            "s", &name)
+          && !tp_strdiff (name, empathy_chatroom_get_name (chatroom)))
         {
-          g_free (tmp);
-          continue;
+          g_menu_remove (self->priv->rooms_section, i);
+          break;
         }
-
-      g_free (tmp);
-
-      if (!g_menu_model_get_item_attribute (
-            G_MENU_MODEL (self->priv->rooms_section), i,
-            "account-path", "s", &tmp))
-        continue;
-
-      if (tp_strdiff (tmp, account_path))
-        {
-          g_free (tmp);
-          continue;
-        }
-
-      g_menu_remove (self->priv->rooms_section, i);
-      g_free (tmp);
-      break;
     }
 
   chatrooms = empathy_chatroom_manager_get_chatrooms (
@@ -1869,7 +1830,6 @@ static GActionEntry menubar_entries[] = {
 
   { "room_join_new", roster_window_room_join_new_cb, NULL, NULL, NULL },
   { "room_join_favorites", roster_window_room_join_favorites_cb, NULL, NULL, NULL },
-  { "join", roster_window_join_chatroom_menu_activate_cb, "(ss)", NULL, NULL },
   { "room_manage_favorites", roster_window_room_manage_favorites_cb, NULL, NULL, NULL },
 
   { "help_contents", roster_window_help_contents_cb, NULL, NULL, NULL },
